@@ -56,6 +56,15 @@ xofs = {
     'shake256': SHAKE256.new,
 }
 
+_block_sizes = {
+    'sha3_224': 114,
+    'sha3_256': 136,
+    'sha3_384': 104,
+    'sha3_512': 72,
+    'shake128': 168,
+    'shake256': 136,
+}
+
 hashes.update(arbitrary_digest_size_hashes)
 
 
@@ -81,14 +90,53 @@ class Hash(base.BaseHash):
         except AttributeError:  # for SHAKE
             return self._digest_size
 
+    @property
+    def block_size(self):
+        """Block size of the underlying hash algorithm."""
+        try:
+            return self._hasher.block_size
+        except AttributeError:
+            try:
+                return _block_sizes[self.name]
+            except KeyError:
+                pass  # raise below
+            raise AttributeError(f'Hash algorithm {self.name} does not '
+                                 'have block_size parameter.') from None
+
     @property
     def name(self):
         return self._name
 
+    @property
+    def oid(self):
+        """ASN.1 Object ID of the hash algorithm."""
+        try:
+            return self._hasher.oid
+        except AttributeError:
+            base_msg = 'oid is avaliable only for digest sizes '
+            # for BLAKE-2b/2s
+            if self.name == 'blake2b':
+                msg = base_msg + '20, 32, 48 and 64'
+            elif self.msg == 'blake2s':
+                msg = base_msg + '16, 20, 28 and 32'
+            else:
+                msg = f'oid attribute is not available for hash {self.name}'
+            raise AttributeError(msg) from None
+
     @base.before_finalized
     def update(self, data):
         self._hasher.update(data)
 
+    @base.before_finalized
+    def copy(self):
+        hashobj = Hash(self.name, digest_size=self.digest_size)
+        try:
+            hashobj._hasher = self._hasher.copy()
+        except AttributeError:
+            raise AttributeError(
+                f'Hash {self.name} does not support copying.') from None
+        return hashobj
+
     @base.finalizer(allow=True)
     def digest(self):
         if self._name in xofs:
@@ -96,7 +144,7 @@ class Hash(base.BaseHash):
         return self._hasher.digest()
 
     def new(self, data=b'', *, digest_size=None):
-        return Hash(
+        return type(self)(
             self.name,
             data,
             digest_size=digest_size or self.digest_size,
